@@ -38,6 +38,14 @@ func (h *Handler) processFiles(dir string, files []os.FileInfo, opcfg *v1.Config
 			}
 			h.imagestreamFile[imagestream.Name] = path
 			metrics.AddStream(imagestream.Name)
+			if !strings.HasPrefix(imagestream.Name, "jenkins") {
+				for _, tag := range imagestream.Spec.Tags {
+					if tag.From != nil && tag.From.Kind != "DockerImage" {
+						continue
+					}
+					h.imagestreatagToImage[imagestream.Name+"_"+tag.Name] = tag.From.Name
+				}
+			}
 			continue
 		}
 
@@ -61,6 +69,8 @@ func (h *Handler) GetBaseDir(arch string, opcfg *v1.Config) (dir string) {
 		dir = x86ContentRootDir
 	case v1.AMDArchitecture:
 		dir = x86ContentRootDir
+	case v1.ARMArchitecture:
+		dir = armContentRootDir
 	case v1.PPCArchitecture:
 		dir = ppcContentRootDir
 	case v1.S390Architecture:
